﻿[CmdletBinding()]
param(
	[Parameter(Position=0, Mandatory=$true)]
	[System.String]
	$CSVFile,
	[Parameter(Position=1, Mandatory=$false)]
	[System.String]
	$PasswordLength = 8,
	[Parameter(Position=2, Mandatory=$false)]
	[System.String]
	$NonAlphanumericCharacters = 0,
	[Parameter(Position=3, Mandatory=$true)]
	[System.String]
	$ReportFile
	)
	
begin {
	Add-Type -AssemblyName System.Web
	$mailboxes = Import-Csv $CSVFile
	$props = $mailboxes | gm -MemberType NoteProperty | select -ExpandProperty Name
	$report = @()
}

process {
	foreach($mailbox in $mailboxes) {
		$i++
		Write-Progress -Activity "Creating Mailboxes..." -Status "Progress:" -PercentComplete ($i/$mailboxes.count*100)		
		$properties = @{}
		$props | %{
			$properties.add($_,$mailbox.$_)
		}
		$password = [System.Web.Security.Membership]::GeneratePassword($PasswordLength,$NonAlphanumericCharacters)
		$securepassword = ConvertTo-SecureString -AsPlainText $password -Force
		$properties.add("Password",$securepassword)

		if(New-Mailbox @properties) {
			$mailbox | Add-Member -MemberType NoteProperty -Name Password -Value $Password
			$report += $mailbox			
		}
		$properties.clear()
	}
}

end {
	$report | Export-Csv -Path $ReportFile -NoTypeInformation
}